function [ Delta2, nnvar ] = calcDelta2( A, tau, fwhm, varargin )
%Calculate Delta2 using neural network from CLS parameters (A, tau [ps]) and
%fwhm (cm-1) of absorption spectrum.

%Delta2: output of NN in (cm-1)
%nnvar: Neural network variance from calculation

    if (A(2) > 0) %If A(2) is nonzero
        c = 2.99792458e-2; %speed of light in cm/ps
        taufull = [tau, 1e6];
        log_s = log10(fwhm*2*pi*c*taufull.*sqrt(A/sum(A)));                 %calculate rescaled CLS parameter s

        data_in = [A(1), log_s(1), A(2), log_s(2) A(3)+A(4)]';              %Set up NN input
        sigma2 = 10^logSigma2ANN(data_in);                                 %Calculate rescaled FFCF parameter sigma2 from NN
        Delta2 = sigma2/(2*pi*c*taufull(2));                                %Calculate Delta2 from sigma2
        

    else %If A(2) is zero
        Delta2 = 0;
    end
    nnvar = (Delta2 * log(10) * 0.01173)^2; %Calculate variance from error propagation
 
end