function [FWHM] = calc_fwhm_mod(omega,S1D, peak_center)
%Calculate FWHM of absorption line shape S1D with frequency axis omega
%centered at peak_center

omega1Dmin = (min(omega));
omega1Dmax = (max(omega));
dOmega = (omega1Dmax-omega1Dmin)/5000;
omega_spl = omega1Dmin:dOmega:omega1Dmax; %Create denser freq. axis
S1D_spl = spline(omega,S1D,omega_spl);    %Interpolate absorption line shape

%redefine interpolated variables
omega1D = omega_spl;
S1D = S1D_spl;

%split frequency axis and absorption spectrum relative to peak center
index_omega_left = omega1D <= peak_center;
index_omega_right = omega1D >= peak_center;
omega1D_left = omega1D(index_omega_left);
omega1D_right = omega1D(index_omega_right);
S1D_left = S1D_spl(index_omega_left);
S1D_right = S1D(index_omega_right);

%The half maximum
HM = max(S1D)/2;

%Find index nearest to half maximum of S1D on both sides
index_HM_left = find(S1D_left >= HM,1);
index_HM_right = find(S1D_right <= HM,1);

%calculate FWHM from calculated indexes
FWHM = abs(omega1D_right(index_HM_right)-omega1D_left(index_HM_left));




