function [val, err ] = calc_value_w_error(f, par, covar)
%calc_value_w_error Get FFCF component and 
%{
%
inputs:
    f: function for calculating a FFCF component from CLS parameter

    par in following order:
    par(1) = A_inf (CLS offset)
    par(2) = A_1
    par(3) = tau_1 (ps)
    par(4) = A_2
    par(5) = tau_2 (ps)
    par(6) = A_3
    par(7) = tau_3 (ps)
    par(8) = fwhm  (cm^-1)

    covar: Covariance matrix for input 

output:
    val: output FFCF parameter
    err: std. err. for FFCF parameter
%}

    [A, tau, fwhm] = funcParWrapper(par); %Sort parameters by type

    [val, nnvar] = f(A,tau,fwhm,1);       %Calculate value and NNerror for FFCF parameter
    
    npar = length(par);
    h=.02;
    
    newpar1 = repmat(par,1,npar) + diag(h*par); %Get displaced parameters for calculating gradients

    deriv = zeros(1,length(par));
    for i = 1:length(par)   %Calculate gradient for each nonzero parameter
        if sum(covar(i,:).^2) ~= 0
            [A, tau, fwhm] = funcParWrapper(newpar1(:,i)); %Sort new parameters by type
            deriv(i) = (f(A,tau,fwhm)-val)/(h*par(i));     %Calculate gradient for parameter
        end
    end
   err = sqrt(deriv*covar*deriv'+nnvar); %Get total error from gradient and NNerror
end

