function gt = g_exact( t, Delta, Tau, T2 )
% Calculates the lineshape function g(t) given the Delta and Tau (arrays) for a
% multiexponential FFCF, and the dephasing time T2.
% C(t) = delta(t)/T2 + sum_i Delta_i^2 exp(-t/Tau_i)
% Delta in rad/ps, Tau in ps, delta(x) the Dirac delta function
%
% In general:
% g(t) = int_0^t dtau2 int_0_tau2 dtau1 C(tau1) = int_0^t dtau (t - tau) C(tau)
% For this case, analytical solution possible:
% g(t) = sum_i Delta_i^2 (Tau_i^2 (exp(-t/Tau_i) - 1) + Tau_i * t)
%
% PLK 10/15/2015

gt = t./T2;
% Only use the inhomogeneous part if Delta and Tau have matching elements
nDelta = length(Delta);
if nDelta == length(Tau)
    for k = 1:nDelta
        if Tau (k) == Inf
        gt = gt + Delta(k)^2 * (t.^2)/2;
        else
        gt = gt + Delta(k)^2 * ((Tau(k)^2) * (exp(-t/Tau(k)) - 1) + Tau(k)*t);
        end
    end
end

end